@@ -7,12 +7,17 @@ abstractions or collections of instances (e.g., subgraphs, etc)
 from jaseci.element.element import element
 from jaseci.jac.interpreter.architype_interp import architype_interp
 from jaseci.jac.ir.jac_code import jac_code
+from jaseci.utils.id_list import id_list
 
 
 class architype(element, jac_code, architype_interp):
     """Architype class for Jaseci"""
 
     def __init__(self, code_ir=None, *args, **kwargs):
+        self.entry_action_ids = id_list(self)
+        self.activity_action_ids = id_list(self)
+        self.exit_action_ids = id_list(self)
+        self._can_compiled_flag = False
         element.__init__(self, *args, **kwargs)
         jac_code.__init__(self, code_ir)
         architype_interp.__init__(self)
@@ -29,4 +34,9 @@ class architype(element, jac_code, architype_interp):
         """
         Destroys self from memory and persistent storage
         """
+        des = self.activity_action_ids.obj_list() + \
+            self.entry_action_ids.obj_list() + \
+            self.exit_action_ids.obj_list()
+        for i in des:
+            i.destroy()
         super().destroy()
