@@ -19,6 +19,7 @@ class sentinel_api():
 
     @interface.private_api(cli_args=['code'])
     def sentinel_register(self, name: str = 'default', code: str = '',
+                          code_dir: str = './',
                           encoded: bool = False, auto_run: str = 'init',
                           auto_gen_graph: bool = True, ctx: dict = {},
                           set_active: bool = True):
@@ -37,7 +38,7 @@ class sentinel_api():
         if(code):
             if (encoded):
                 code = b64decode_str(code)
-            snt.register_code(code)
+            snt.register_code(code, code_dir)
             if(not snt.is_active):
                 return {'response': 'Error in jac code',
                         'errors': snt.errors,
@@ -92,7 +93,8 @@ class sentinel_api():
             return snt.serialize(detailed=detailed)
 
     @interface.private_api(cli_args=['code'])
-    def sentinel_set(self, code: str, encoded: bool = False,
+    def sentinel_set(self, code: str, code_dir: str = './',
+                     encoded: bool = False,
                      snt: sentinel = None, mode: str = 'default'):
         """
         Set code/ir for a sentinel, only replaces walkers/archs in sentinel
@@ -101,7 +103,7 @@ class sentinel_api():
         if (encoded):
             code = b64decode_str(code)
         if(mode == 'code' or mode == 'default'):
-            snt.register_code(code)
+            snt.register_code(code, code_dir)
         elif(mode == 'ir'):
             snt.apply_ir(code)
             snt.run_start(snt._jac_ast)
