@@ -804,3 +804,15 @@ class jac_tests(TestCaseHelper, TestCase):
         report = test_walker.report
         self.assertEqual(report, ['hello'])
         self.assertEqual(test_walker.report_status, 302)
+
+    def test_graph_in_graph(self):
+        self.logger_on()
+        gph = graph(m_id='anon', h=mem_hook())
+        sent = sentinel(m_id='anon', h=gph._h)
+        sent.register_code(jtc.graph_in_graph)
+        test_walker = \
+            sent.walker_ids.get_obj_by_name('init')
+        test_walker.prime(gph)
+        test_walker.run()
+        report = test_walker.report
+        self.assertEqual(len(report), 3)
